''' -----------------------------------------------------------------------------
''' Project	 : Objects
''' Class	 : Objects.MedPrescription
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' This MedPrescription object contains the properties of a prescription. 
''' </summary>
''' Note: The following properties can be used when the prescription is for a 
''' single SIG: Frequency, NumberOfDays, Quantity, QuantityUnit, Route, Site, 
''' and RxWhen. If the prescription object needs to store more than one SIG,
''' use the AddSIG method to add SIG items rather than use the individual
''' properties. It is acceptable to use the SIG collection for a single SIG.
''' <remarks>
''' </remarks>
''' <history>
''' 	[roy]	2/18/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public Class MedPrescription
    Private myRxid As Integer
    Private myDoseid As Integer
    Private myBrandid As Integer
    Private myPid As String
    Private myEncounterDate As Date
    Private myMedcinID As Integer
    Private myStrength As Single
    Private myStrengthUnit As String
    Private myForm As String
    Private myIv As String
    Private myQuantity As Single
    Private myQuantityUnit As String
    Private myRoute As String
    Private myFrequency As String
    Private myRxWhen As String
    Private myNumberOfDays As Short
    Private myAmount As Integer
    Private myFormPackage As String
    Private myNumberOfRefills As Short
    Private myGeneric As String
    Private myDocid As Integer
    Private myBrandName As String
    Private myLot As String
    Private myPrefix As String
    Private myNote As String
    Private myManufacturerName As String
    Private mySite As String
    Private myRxString As String
    Private myChanged As Boolean
    Private myNDC As String
    Private mycSIGs As Collection

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' This constructor creates a new MedPrescription object.
    ''' </summary>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New()
        mycSIGs = New Collection
    End Sub

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' This constructor assigns the RxId to the newly created object.
    ''' </summary>
    ''' <param name="RxID">The RxId to assign to the newly created object</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New(ByVal RxID As Integer)
        mycSIGs = New Collection
        myRxid = RxID
    End Sub

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' This constructor assigns the RxString to the newly created object.
    ''' </summary>
    ''' <param name="RxString">The RxString to assign to the newly created object.</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	5/12/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub New(ByVal RxString As String)
        mycSIGs = New Collection
        myRxString = RxString
    End Sub

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Clone creates a duplicate of the prescription as a new MedPrescription object.
    ''' </summary>
    ''' <returns>A reference to the newly created MedPrescription object is returned.</returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Function Clone() As MedPrescription
        Dim newObject As MedPrescription
        Dim objSIG As MedSIG
        If (Me Is Nothing) Then
            Clone = Nothing
        Else
            newObject = New MedPrescription
            With newObject
                ' Rx
                .Docid = myDocid
                .Doseid = myDoseid
                .EncounterDate = myEncounterDate
                .Form = myForm
                .Pid = myPid
                .Prefix = myPrefix
                .Rxid = myRxid
                .IV = myIv
                .MedcinID = myMedcinID
                .NDC = myNDC
                .Note = myNote
                .Strength = myStrength
                .StrengthUnit = myStrengthUnit

                ' SIG
                .Frequency = myFrequency
                .NumberOfDays = myNumberOfDays
                .Quantity = myQuantity
                .QuantityUnit = myQuantityUnit
                .Route = myRoute
                .Site = mySite
                .RxWhen = myRxWhen
                For Each objSIG In mycSIGs
                    .AddSIGObject(objSIG.Clone)
                Next objSIG

                ' DISP
                .Amount = myAmount
                .Brandid = myBrandid
                .BrandName = myBrandName
                .FormPackage = myFormPackage
                .Generic = myGeneric
                .Lot = myLot
                .ManufacturerName = myManufacturerName
                .NumberOfRefills = myNumberOfRefills

                .Changed = myChanged
            End With
            Clone = newObject
        End If
    End Function

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' This allows you to remove a MedSIG object from the SIG collection.
    ''' </summary>
    ''' <param name="IndexKey">The index or key of the item.</param>
    ''' <remarks>
    ''' An attempt to remove an MedPrescription item that is not in the collection
    ''' will not throw an exception.
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/22/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub RemoveSIG(ByVal IndexKey As Object)
        Try
            mycSIGs.Remove(IndexKey)
        Catch

        End Try
    End Sub

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Adds the passed data as a SIG object to the SIGs collection and returns an 
    ''' instance of that SIG object
    ''' </summary>
    ''' <param name="Quantity">The numerical quantity of the medication.</param>
    ''' <param name="Unit">One of the qualifier codes identified for 'RXQUANUNIT'.</param>
    ''' <param name="Route">One of the qualifier codes identified for 'RXROUTE'.</param>
    ''' <param name="Days">Number of days prescribed.</param>
    ''' <param name="Frequency">Frequency is one of the qualifier codes identified for 'RXFREQ'.</param>
    ''' <param name="RxWhen">One of the qualifier codes identified for 'RXWHEN'.</param>
    ''' <param name="Site">One of the qualifier codes identified for 'RXSITE*'.</param>
    ''' <param name="Key">Optional. A unique String expression that specifies a key 
    ''' string that can be used instead of a positional index to access a member of 
    ''' the collection.</param>
    ''' <returns>A reference to the newly created MedSIG object is returned.</returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Function AddSIG(ByVal Quantity As Single, ByVal Unit As String, ByVal Route As String, ByVal Days As Short, ByVal Frequency As String, ByVal RxWhen As String, ByVal Site As String, Optional ByVal Key As String = "") As MedSIG
        Dim objSIG As MedSIG
        On Error Resume Next
        objSIG = New MedSIG
        objSIG.Frequency = Frequency
        objSIG.Days = Days
        objSIG.Quantity = Quantity
        objSIG.Unit = Unit
        objSIG.Route = Route
        objSIG.Site = Site
        objSIG.RxWhen = RxWhen
        If Len(Key) = 0 Then
            mycSIGs.Add(objSIG)
        Else
            mycSIGs.Add(objSIG, Key)
        End If
        AddSIG = objSIG
    End Function

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Adds the passed SIG object to the SIGs ollection.
    ''' </summary>
    ''' <param name="oSIG">The MedSIG to add.</param>
    ''' <param name="Key">Optional. A unique String expression that specifies a key 
    ''' string that can be used instead of a positional index to access a member of 
    ''' the collection.</param>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Sub AddSIGObject(ByVal oSIG As MedSIG, Optional ByVal Key As String = "")
        Try
            If Len(Key) = 0 Then
                mycSIGs.Add(oSIG)
            Else
                mycSIGs.Add(oSIG, Key)
            End If
        Catch

        End Try
    End Sub

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' The ToString override provides an abbreviated form of the prescription data 
    ''' in string form that may be useful for presentation in a narrative.
    ''' </summary>
    ''' <returns>Partial prescription data in string form.</returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Overrides Function ToString() As String
        If (Not myRxString Is Nothing) Then
            Return myRxString
        Else
            Return RxToString(Me)
        End If
    End Function

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Allows application to pass a formatted Rx string of data
    ''' </summary>
    ''' <value>A formatted string of data representing the prescription</value>
    ''' <remarks>
    ''' If this property is a string, the ToString function will return it, otherwise
    ''' the ToString function will return a formatted string representation of the
    ''' individual properties of the object.
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	5/12/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property RxString() As String
        Get
            Return myRxString
        End Get
        Set(ByVal Value As String)
            myRxString = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Brandid is the brand identification.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Brandid() As Integer
        Get
            Return myBrandid
        End Get
        Set(ByVal Value As Integer)
            myBrandid = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Doseid is the identification number of the dosage 
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Doseid() As Integer
        Get
            Return myDoseid
        End Get
        Set(ByVal Value As Integer)
            myDoseid = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Rxid is used by your application as a unique reference to the database 
    ''' storage of the object.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Rxid() As Integer
        Get
            Return myRxid
        End Get
        Set(ByVal Value As Integer)
            myRxid = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Pid is our patient identifier.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Pid() As String
        Get
            Return myPid
        End Get
        Set(ByVal Value As String)
            myPid = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' EncounterDate is the encounter date of the object.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property EncounterDate() As Date
        Get
            Return myEncounterDate
        End Get
        Set(ByVal Value As Date)
            myEncounterDate = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' MedcinID is the Medcin identifier for the finding.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property MedcinID() As Integer
        Get
            Return myMedcinID
        End Get
        Set(ByVal Value As Integer)
            myMedcinID = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Strength is the numerical strength of the medication.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Strength() As Single
        Get
            Return myStrength
        End Get
        Set(ByVal Value As Single)
            myStrength = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' StrengthUnit is one of the qualifier codes identified for 'RXSTRUNIT'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property StrengthUnit() As String
        Get
            Return myStrengthUnit
        End Get
        Set(ByVal Value As String)
            myStrengthUnit = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Form is one of the qualifier codes identified for 'RXFORM'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Form() As String
        Get
            Return myForm
        End Get
        Set(ByVal Value As String)
            myForm = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' IV is a string describing an intravenous injection.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property IV() As String
        Get
            Return myIv
        End Get
        Set(ByVal Value As String)
            myIv = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Quantity is the numerical quantity of the medication.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Quantity() As Single
        Get
            Return myQuantity
        End Get
        Set(ByVal Value As Single)
            myQuantity = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' QuantityUnit is one of the qualifier codes identified for 'RXQUANUNIT'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property QuantityUnit() As String
        Get
            Return myQuantityUnit
        End Get
        Set(ByVal Value As String)
            myQuantityUnit = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Route is one of the qualifier codes identified for 'RXROUTE'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Route() As String
        Get
            Return myRoute
        End Get
        Set(ByVal Value As String)
            myRoute = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Frequency is one of the qualifier codes identified for 'RXFREQ'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Frequency() As String
        Get
            Return myFrequency
        End Get
        Set(ByVal Value As String)
            myFrequency = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' RxWhen is one of the qualifier codes identified for 'RXWHEN'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property RxWhen() As String
        Get
            Return myRxWhen
        End Get
        Set(ByVal Value As String)
            myRxWhen = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' NumberOfDays is the number of days prescribed.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property NumberOfDays() As Short
        Get
            Return myNumberOfDays
        End Get
        Set(ByVal Value As Short)
            myNumberOfDays = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Amount is the numerical amount of the medication.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Amount() As Integer
        Get
            Return myAmount
        End Get
        Set(ByVal Value As Integer)
            myAmount = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' FormPackage is one of the qualifier codes identified for 'RXAMOUNT'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property FormPackage() As String
        Get
            Return myFormPackage
        End Get
        Set(ByVal Value As String)
            myFormPackage = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' NumberOfRefills is the number of refills allowed.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property NumberOfRefills() As Short
        Get
            Return myNumberOfRefills
        End Get
        Set(ByVal Value As Short)
            myNumberOfRefills = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Indicates whether or not a generic drug is permitted. Should be 'Y' or 'N'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Generic() As String
        Get
            Return myGeneric
        End Get
        Set(ByVal Value As String)
            myGeneric = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Docid is your reference id for the responsible provider.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Docid() As Integer
        Get
            Return myDocid
        End Get
        Set(ByVal Value As Integer)
            myDocid = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Brand name prescribed (e.g. Bayer, Tylenol)
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property BrandName() As String
        Get
            Return myBrandName
        End Get
        Set(ByVal Value As String)
            myBrandName = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' The lot number prescribed for the medication.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Lot() As String
        Get
            Return myLot
        End Get
        Set(ByVal Value As String)
            myLot = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for the Medcin QualifierList 'RXPREFIX'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Prefix() As String
        Get
            Return myPrefix
        End Get
        Set(ByVal Value As String)
            myPrefix = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' A free text note attached to the prescription.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Note() As String
        Get
            Return myNote
        End Get
        Set(ByVal Value As String)
            myNote = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' The name of the company making the drug.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property ManufacturerName() As String
        Get
            Return myManufacturerName
        End Get
        Set(ByVal Value As String)
            myManufacturerName = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXSITE*'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Site() As String
        Get
            Return mySite
        End Get
        Set(ByVal Value As String)
            mySite = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Used by your application to indicate that the prescription data hs been changed.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Changed() As Boolean
        Get
            Return myChanged
        End Get
        Set(ByVal Value As Boolean)
            myChanged = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' The  10-digit national drug code.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property NDC() As String
        Get
            Return myNDC
        End Get
        Set(ByVal Value As String)
            myNDC = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' This is used to obtain a reference to the collection of MedSig objects 
    ''' in the prescription.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public ReadOnly Property cSIGs() As Collection
        Get
            Return mycSIGs
        End Get
    End Property

    Private Function RxToString(ByVal oRx As MedPrescription) As String
        Dim strOut As String = ""
        Dim strSig As String
        Dim objSIG As MedSIG
        Try
            If (oRx Is Nothing) Then
                RxToString = ""
                Exit Function
            End If
            With oRx
                If (Len(oRx.NDC) > 0) Then strOut = oRx.NDC & ": "
                strOut = strOut & oRx.Strength
                If (Len(oRx.StrengthUnit) > 0) Then strOut = strOut & " " & oRx.StrengthUnit
                If (Len(oRx.Form) > 0) Then strOut = strOut & " " & oRx.Form
                If (Len(oRx.IV) > 0) Then strOut = strOut & " " & oRx.IV

                strSig = ""
                If (Len(oRx.Site) > 0) Then strSig = "At:" & oRx.Site
                If (oRx.Quantity > 0) Then strSig = strSig & " " & oRx.Quantity
                If (Len(oRx.QuantityUnit) > 0) Then strSig = strSig & " " & oRx.QuantityUnit
                If (Len(oRx.Route) > 0) Then strSig = strSig & " " & oRx.Route
                If (Len(oRx.Frequency) > 0) Then strSig = strSig & " " & oRx.Frequency
                If (Len(oRx.RxWhen) > 0) Then strSig = strSig & " " & oRx.RxWhen
                If (oRx.NumberOfDays > 0) Then strSig = strSig & " " & oRx.NumberOfDays
                If (Len(strSig) > 0) Then
                    strOut = strOut & " (" & Trim(strSig) & ")"
                End If

                If (oRx.cSIGs.Count > 0) Then
                    For Each objSIG In oRx.cSIGs
                        With objSIG
                            strSig = ""
                            If (Len(objSIG.Site) > 0) Then strSig = "At:" & objSIG.Site
                            If (objSIG.Quantity > 0) Then strSig = strSig & " " & objSIG.Quantity
                            If (Len(objSIG.Unit) > 0) Then strSig = strSig & " " & objSIG.Unit
                            If (Len(objSIG.Route) > 0) Then strSig = strSig & " " & objSIG.Route
                            If (Len(objSIG.Frequency) > 0) Then strSig = strSig & " " & objSIG.Frequency
                            If (Len(objSIG.RxWhen) > 0) Then strSig = strSig & " " & objSIG.RxWhen
                            If (objSIG.Days > 0) Then strSig = strSig & " " & objSIG.Days
                        End With
                        If (Len(strSig) > 0) Then
                            strOut = strOut & " " & Trim(strSig) & ";"
                        End If
                    Next
                End If

                If (oRx.Amount > 0) Then strOut = strOut & " DISP:" & oRx.Amount
                If (Len(oRx.FormPackage) > 0) Then strOut = strOut & " " & oRx.FormPackage
                If (oRx.NumberOfRefills > 0) Then strOut = strOut & " Refill:" & oRx.NumberOfRefills
                strOut = strOut & " Generic:" & oRx.Generic
                If (Len(oRx.BrandName) > 0) Then strOut = strOut & " Using:" & oRx.BrandName
                If (Len(oRx.Lot) > 0) Then strOut = strOut & " Lot:" & oRx.Lot
                If (Len(oRx.ManufacturerName) > 0) Then strOut = strOut & " Mfg:" & oRx.ManufacturerName
                If (Len(oRx.Note) > 0) Then strOut = strOut & " Note:" & oRx.Note
            End With
            RxToString = strOut
        Catch ex As Exception
            RxToString = ex.Message
        End Try
    End Function
End Class

''' -----------------------------------------------------------------------------
''' Project	 : Objects
''' Class	 : Objects.MedSIG
''' 
''' -----------------------------------------------------------------------------
''' <summary>
''' This MedSIG object contains the properties of a prescription SIG.
''' </summary>
''' <remarks>
''' This can be used when the prescription contains multiple SIGs.
''' </remarks>
''' <history>
''' 	[roy]	2/23/2005	Created
''' </history>
''' -----------------------------------------------------------------------------
Public Class MedSIG
    Private myFrequency As String
    Private myDays As Short
    Private myQuantity As Single
    Private myUnit As String
    Private myRoute As String
    Private mySite As String
    Private myRxWhen As String

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXFREQ'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Frequency() As String
        Get
            Return myFrequency
        End Get
        Set(ByVal Value As String)
            myFrequency = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Number of days prescribed.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Days() As Short
        Get
            Return myDays
        End Get
        Set(ByVal Value As Short)
            myDays = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' The numerical quantity of the medication.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Quantity() As Single
        Get
            Return myQuantity
        End Get
        Set(ByVal Value As Single)
            myQuantity = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXQUANUNIT'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Unit() As String
        Get
            Return myUnit
        End Get
        Set(ByVal Value As String)
            myUnit = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXROUTE'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Route() As String
        Get
            Return myRoute
        End Get
        Set(ByVal Value As String)
            myRoute = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXSITE*'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property Site() As String
        Get
            Return mySite
        End Get
        Set(ByVal Value As String)
            mySite = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' One of the qualifier codes identified for 'RXWHEN'.
    ''' </summary>
    ''' <value></value>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Property RxWhen() As String
        Get
            Return myRxWhen
        End Get
        Set(ByVal Value As String)
            myRxWhen = Value
        End Set
    End Property

    ''' -----------------------------------------------------------------------------
    ''' <summary>
    ''' Clone is used to obtain a duplicate of the object
    ''' </summary>
    ''' <returns>Returns a new MedSig object containing properties identical to the object.</returns>
    ''' <remarks>
    ''' </remarks>
    ''' <history>
    ''' 	[roy]	2/23/2005	Created
    ''' </history>
    ''' -----------------------------------------------------------------------------
    Public Function Clone() As MedSIG
        Dim oSig As MedSIG
        oSig = New MedSIG
        With oSig
            .Days = myDays
            .Frequency = myFrequency
            .Quantity = myQuantity
            .Route = myRoute
            .RxWhen = myRxWhen
            .Site = mySite
            .Unit = myUnit
        End With
        Clone = oSig
        oSig = Nothing
    End Function
End Class